@@ -293,7 +293,7 @@ def get_bins_len_from_bg_dir(bg_dir, percent):
         return bin_seq
 
 
-def generate_len_sequences(fg, bg, bg_dir, nfold):
+def generate_len_sequences(fg, bg, bg_dir, nfold, random_seed):
     """
     Extract the sequences from the bg with similar sizes as in the fg.
 
@@ -301,6 +301,7 @@ def generate_len_sequences(fg, bg, bg_dir, nfold):
 
     """
 
+    random.seed(random_seed)
     sys.setrecursionlimit(10000)
     lengths = []
     gc_list = []
